.. zhihu-py3 documentation master file, created by
   sphinx-quickstart on Sun Feb 22 23:01:19 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to zhihu-py3's documentation!
=====================================

Contents:

..  toctree::
    :maxdepth: 2

    install
    examples
    login
    classes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
